==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/GetStaticSitePrivateEndpointConnectionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the static site.
 * @property privateEndpointConnectionName Name of the private endpoint connection.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class GetStaticSitePrivateEndpointConnectionPlainArgs(
    public val name: String,
    public val privateEndpointConnectionName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs =
        com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .privateEndpointConnectionName(privateEndpointConnectionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetStaticSitePrivateEndpointConnectionPlainArgs].
 */
@PulumiTagMarker
public class GetStaticSitePrivateEndpointConnectionPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var privateEndpointConnectionName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the static site.
     */
    @JvmName("yoavbkqmtodcaamd")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the private endpoint connection.
     */
    @JvmName("tubfpgporhgmdpbd")
    public suspend fun privateEndpointConnectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateEndpointConnectionName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("bvptxbdnvlsbrjrk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetStaticSitePrivateEndpointConnectionPlainArgs =
        GetStaticSitePrivateEndpointConnectionPlainArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            privateEndpointConnectionName = privateEndpointConnectionName ?: throw
                PulumiNullFieldException("privateEndpointConnectionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/GetStaticSitePrivateEndpointConnectionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the static site.
 * @property privateEndpointConnectionName Name of the private endpoint connection.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class GetStaticSitePrivateEndpointConnectionPlainArgs(
    public val name: String,
    public val privateEndpointConnectionName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs =
        com.pulumi.azurenative.web.inputs.GetStaticSitePrivateEndpointConnectionPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .privateEndpointConnectionName(privateEndpointConnectionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetStaticSitePrivateEndpointConnectionPlainArgs].
 */
@PulumiTagMarker
public class GetStaticSitePrivateEndpointConnectionPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var privateEndpointConnectionName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the static site.
     */
    @JvmName("edtsccpfofvpdllv")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the private endpoint connection.
     */
    @JvmName("cceanjvnykqelpkh")
    public suspend fun privateEndpointConnectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateEndpointConnectionName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("goybjoxicbsaaycm")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetStaticSitePrivateEndpointConnectionPlainArgs =
        GetStaticSitePrivateEndpointConnectionPlainArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            privateEndpointConnectionName = privateEndpointConnectionName ?: throw
                PulumiNullFieldException("privateEndpointConnectionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
